
# Slot: ~~is_usage_slot~~ _(deprecated)_


True means that this slot was defined in a slot_usage situation

URI: [linkml:is_usage_slot](https://w3id.org/linkml/is_usage_slot)


## Domain and Range

slot_definition &#8594;  <sub>0..1</sub> boolean

## Parents


## Children


## Used by

 * slot_definition
